
import rclpy
from rclpy.node import Node

from rclpy.callback_groups import ReentrantCallbackGroup

from interaction_msgs.srv import Query

from .optimizers.bayesian_optimization import BayesianOptimization

import numpy as np
import time
import os


class BayesianOptimizationNode(Node):
    def __init__(self):
        super().__init__('bayesian_optimization_node')

        # reading parameters
        self.kernel_type = self.declare_parameter('kernel_type', 'Matern').get_parameter_value().string_value
        self.acquisition_function_name = (self.declare_parameter('acquisition_function_name', 'EI')
                                     .get_parameter_value().string_value)

        # Subscribers

        # Publishers

        # Service Clients
        self.query_client = self.create_client(Query, 'user_query')

        # Bayesian Optimization
        self.bayesian_optimization = None
        self.nr_bo_steps = 100
        self.nr_dimensions = 1
        self.nr_policy_parameters = 10

        self.nr_init = 3
        self.seed = None
        self.lower_bound = None
        self.upper_bound = None

    def reset_bo(self, fixed_dimensions=None, **kwargs):
        self.bayesian_optimization = BayesianOptimization(self.nr_bo_steps,
                                                          self.nr_dimensions,
                                                          self.nr_policy_parameters,
                                                          seed=self.seed,
                                                          fixed_dimensions=fixed_dimensions,
                                                          lower_bound=self.lower_bound,
                                                          upper_bound=self.upper_bound,
                                                          acquisition_function_name=self.acquisition_function_name,
                                                          kernel_type=self.kernel_type, **kwargs)




